queueName property
macOS system queue ID. These printers use the native printing backend regardless of their USB, network, or unknown connection type.
Implementation
final String? queueName;
macOS system queue ID. These printers use the native printing backend regardless of their USB, network, or unknown connection type.
final String? queueName;